# Supplementary data on the research of Gyroscopic upper-body balance perturbations

This dataset was collected during perturbation experiment in August and September 2018 in Delft, Netherlands at the Department of Biomechanical Engineering. In the conducted experiment subjects were asked to stand still while undergoing artificial torque perturbations (up to 50 Nm) that were applied to the trunk of the subjects. The dataset contains processed biomechanical measurement data of kinematic, kinetic, electromyographic and internal states of the Angular Momentum Perturbation (AMP) as well as (anonymised) anthrometric parameters. It is being made public both to act as supplementary data for publications and the PhD thesis of Christian Schumacher and in order for other researchers to use this data in their own work.

**Please refer to the referenced paper for methodological details of the collection and processing that resulted in this dataset:**

C. Schumacher, A. Berry, D. Lemus Perez, C. Rode, A. Seyfarth and H. Vallery (2019) Biarticular Muscles are most responsive to Upper-body Pitch Perturbations in Human Standing. Scientific reports. 

## Explanation of data files

This dataset contains data files stored in the MAT file format (version 7.3) of the numerical computing software MATLAB (The MathWorks Inc., Natick, USA):

**1_SUBJECTS.mat**   
Mean and standard deviation (SD) of all analyzed subjects. Contains information about age, body mass and body height.

**2_KINEMATICS.mat**  
Mean timeseries of all eleven analyzed subjects, separated for positive and negative perturbation. Contains timeseries of trunk pitch, roll and yaw, marker trajectories of body Center of Mass (COM), Angular Momentum Perturbator (AMP) COM, shoulder joint (SHO), hip joint (HIP), knee joint (KNEE), ankle joint (ANKLE), metatarsal joint (TOE) as well as joint angles of ankle, knee and hip. 

**3_KINETICS.mat**  
Mean timeseries of all eleven analyzed subjects, separated for positive and negative perturbation. Contains timeseries of whole body Center of Pressure (COP) and Ground reaction forces (GRF).

**4_AMP.mat**  
Mean and SD timeseries of internal states of the AMP, separated for positive and negative perturbation. Contains timeseries of desired and actual (estimated) torque (tau).

**5_EMG.mat**
Mean timeseries of all eleven analyzed subjects, separated for positive and negative perturbation, both legs and all muscle groups. Contains timeseries of unloaded condition (UL), loaded condition (L), pre-perturbation (PP), absolute mean EMG values (expressed as WEMG) of response interval 1 (RI1), response interval 2 (RI2), response interval 3 (RI3) as well as relative mean reflex responses (wrt. PP condition) of RI1, RI2 and RI3.


**6_BACKGROUND_EMG.mat**
Averaged peak to mean ratios of the filtered background EMG during level walking of all subjects. Contains ratios for all muscles.

- **Timeseries** were sampled with 1 kHz (1 sample = 1 ms). Each timeseries contains 2500 samples of which the first 500 samples correspond to the 500 ms before the onset of the perturbation. Hence, the perturbation starts at sample 500. 
- The **World coordinate frame** was defined as following wrt. body axes of the subject: x-coordinate denotes lateral axis (positive to the left), y-coordinate denotes forward/backward axis (positive for posterior) and z-coordinate denots vertical axis (positive for upwards).
- All **Units** contained this dataset follow SI convention.
- **Used Variable,  Muscle Abbrevations** are explained below.

## Variable Abbreviations

**Dir:** 
Direction condition: 1 = positive perturbation, 2 = negative perturbation.

**Pos:** 
Initial gimbal position condition: 1 = original position (Block 1), 2 = inverted position (Block 2).

**GRF:** 
Ground reaction forces.

**TOR / tau:** 
Ground reaction torques.

**COP:** 
Center of Pressure.

**COM:** 
Center of Mass.

**EMG:** 
Electromyographic data.

**AMP:** 
Angular momentum perturbator.

## Muscle Abbrevations

**GLU:** 
Gluteus maximus muscle: Extends, laterally rotates and lower fibres assist in adduc- tion of the hip joint. The upper fibres assist in adduction. Through its insertion into the iliotibial tract, helps to stabilise the knee in extension [Hermens2000].

**TFL:** 
Tensor faciae laterale: Flexion and lateral rotation of the knee joint. The long head also extends and assists in lateral rotation of the hip joint [Hermens2000].

**HAM:** 
Biceps femoris long head muscle: Flexion and lateral rotation of the knee joint. The long head extends and assists in lateral rotation of the hip joint [Hermens2000].

**RF:** 
Rectus femoris muscle: Extension of the knee joint and flexion of the hip joint [Hermens2000].

**VL:**
Vastus lateralis muscle: Extension of the knee joint [Hermens2000].
GAS Gastrocnemius lateralis muscle: Flexion of the ankle joint and assist in flexion of the knee joint [Hermens2000].

**SOL:** 
Soleus muscle: Plantar flexion of the ankle joint [Hermens2000].

**TA:** 
Tibialis anterior muscle: Dorsiflexion of the ankle joint and assistance in inversion ofthe foot [Hermens2000].

Muscles are referred by labels in the form [xxx].[R/L]. The first part xxx denotes the two- or three-letter muscle abbreviation as listed above whereas the last part L or R indicates the left or right body side.

## Used Marker Locations

**LTRA, RTRA:**
Left and right tragion: Undepressed skin surface point obtained by palpating the most anterior margin of the cartilaginous notch just superior to the tragus of the ear located at the upper edge of the external auditory meatus [Reed1999].

**C7:** 
7th cervical vertebra: Depressed skin surface point at the most posterior aspect of the spinous process of the 7th cervical vertebra [Reed1999].

**LACR, RACR:**
Left and right acromion: Undepressed skin surface point obtained by palpat- ing the most anterior portion of the lateral margin of the acromial process of the scapula [Reed1999].

**LGTR, RGTR:**
Left and right greater trochanter: Undepressed skin surface point at the most lateral prominent of the upper femur.

**LLFC, RLFC:**
Left and right lateral femoral epicondyle: Undepressed skin surface point at the most lateral aspect of the lateral femoral epicondyle [Reed1999].

**LFIB, RFIB:**
Left and right lateral Fibulare: The superior point of the fibula [mcconville1980anthropometric].

**LLM, RLM:**
Left and right lateral malleoius: Undepressed skin surface point at the most lateral
aspect of the malleolus of the fibula [Reed1999].

**LCAL, RCAL:**
Left and right calcaneus: Undepressed skin surface point at the most posterior promi-
nent of the calcaneus.

**LMT1, RMT1:**
Left and right 1st metatarsal head: Undepressed skin surface point above the distal head of the 1st metatarsal.

**LMT5, RMT5:**
Left and right 5th metatarsal head: Undepressed skin surface point above the distal head of the 5th metatarsal.

Landmarks are referred by labels in the form [R/L][xxx]. The first part L or R indicates the left or right body side (where applicable) whereas the last part xxx denotes the two- or three-letter landmark abbreviation as listed above.


## References

**[Reed1999]**
M P Reed, M A Manary, and L W Schneider. Methods for Measuring and Representing Automobile Occupant Posture. Tech. rep. 724. 1999.

**[hermens1999european]**
Hermie J Hermens, Bart Freriks, Roberto Merletti, Dick Stegeman, Joleen Blok, Günter Rau, Cathy Disselhorst-Klug, and Göran Hägg. “European recommendations for surface electromyography”. In: Roessingh research and development 8.2 (1999), pp. 13–54.

**[mcconville1980anthropometric]**
John T McConville, Charles E Clauser, Thomas D Churchill, Jaime Cuzzi, and Ints Kaleps. Anthropometric relationships of body and body segment moments of inertia. Tech. rep. ANTHROPOLOGY RESEARCH PROJECT INC YELLOW SPRINGS OH, 1980.

## Licence of this dataset

This dataset is licenced under the **CC-BY** (Attribution) license. This licence lets you distribute, remix, tweak, and build upon this work, even commercially, as long as you credit the creators for the original creation.

## Contact

**Christian Schumacher**

schumacher@sport.tu-darmstadt.de  
Technische Universität Darmstadt  
Institue of Sport Science  
Centre for Cognitive Science  
Lauflabor Locomotion Laboratory  
Magdalenenstraße 27, 64289  
Darmstadt, Germany

c.a.schumacher@tudelft.nl  
Technische Universiteit Delft  
Mechanical, Maritime and Materials Engineering  
BioMechanical Engineering  
Delft Biorobotics Lab  
Mekelweg 2, 2628 CD  
Delft, The Netherlands